-- =============================================
-- SaveToDB Framework for Microsoft SQL Server
-- Version 8.11, September 10, 2018
--
-- This script upgrades SaveToDB Framework 8.8 to SaveToDB Framework 8.11
--
-- Copyright 2011-2018 Gartle Technology Corporation
-- =============================================

UPDATE xls.handlers SET HANDLER_CODE = 'Actions, Change, ContextMenu, DoubleClick, SelectionChange, ConvertFormulas, DoNotConvertFormulas, DoNotSelect, DoNotSave, DoNotChange, DoNotAddValidation, DoNotAddChangeHandler, ProtectRows, Formula, FormulaValue, ParameterValues, ValidationList, SelectionList, SyncParameter, DefaultListObject, ManyToMany, DoNotAddManyToMany' WHERE TABLE_SCHEMA = 'xls' AND TABLE_NAME = 'handlers' AND COLUMN_NAME = 'EVENT_NAME' AND EVENT_NAME = 'ValidationList';
GO

CREATE ROLE [xls_formats];
GO

GRANT SELECT, INSERT, UPDATE, DELETE, VIEW DEFINITION ON [xls].[formats] TO [xls_formats];
GO

-- =============================================
-- Author:      Gartle Technology Corporation
-- Release:     8.11, 2018-09-10
-- Description: SaveToDB Query List
-- =============================================

ALTER VIEW [xls].[queries]
AS

SELECT
    s.name AS TABLE_SCHEMA
    , o.name AS TABLE_NAME
    , CASE o.[type] WHEN 'U' THEN 'BASE TABLE' WHEN 'V' THEN 'VIEW' WHEN 'P' THEN 'PROCEDURE' WHEN 'IF' THEN 'FUNCTION' ELSE o.type_desc COLLATE Latin1_General_CI_AS END AS TABLE_TYPE
    , CAST(NULL AS nvarchar(max)) AS TABLE_CODE
    , CAST(NULL AS nvarchar(max)) AS INSERT_PROCEDURE
    , CAST(NULL AS nvarchar(max)) AS UPDATE_PROCEDURE
    , CAST(NULL AS nvarchar(max)) AS DELETE_PROCEDURE
    , CAST(NULL AS nvarchar(50)) AS PROCEDURE_TYPE
FROM
    sys.objects o
    INNER JOIN sys.schemas s ON s.[schema_id] = o.[schema_id]
WHERE
    o.[type] IN ('U', 'V', 'P', 'IF')
    AND (HAS_PERMS_BY_NAME(DB_NAME() + '.' + s.name + '.' + o.name, 'OBJECT', 'SELECT') = 1
        OR HAS_PERMS_BY_NAME(DB_NAME() + '.' + s.name + '.' + o.name, 'OBJECT', 'EXECUTE') = 1)
    AND NOT s.name IN ('sys', 'xls', 'etl01', 'dbo01', 'xls01', 'savetodb_dev', 'savetodb_xls', 'savetodb_etl', 'SAVETODB_DEV', 'SAVETODB_XLS', 'SAVETODB_ETL')
    AND NOT (s.name = 'dbo' AND (
           o.name LIKE 'sp_%'
        OR o.name LIKE 'fn_%'
        OR o.name LIKE 'sys%'
        ))
    AND NOT o.name LIKE 'xl_%'
    AND NOT (o.[type] = 'V' AND (
           o.name LIKE 'viewQueryList%'
        OR o.name LIKE 'viewParameterValues%'
        OR o.name LIKE 'viewValidationList%'
        OR o.name LIKE 'view_query_list%'
        OR o.name LIKE 'view_xl_%'
        OR o.name LIKE 'xl_%'
        ))
    AND NOT (o.[type] = 'P' AND (
           o.name LIKE '%_insert'
        OR o.name LIKE '%_update'
        OR o.name LIKE '%_delete'
        OR o.name LIKE '%_merge'
        OR o.name LIKE '%_change'
        OR o.name LIKE 'uspExcelEvent%'
        OR o.name LIKE 'uspParameterValues%'
        OR o.name LIKE 'uspValidationList%'
        OR o.name LIKE 'uspAdd%'
        OR o.name LIKE 'uspSet%'
        OR o.name LIKE 'uspInsert%'
        OR o.name LIKE 'uspUpdate%'
        OR o.name LIKE 'uspDelete%'
        OR o.name LIKE 'Add%'
        OR o.name LIKE 'Set%'
        OR o.name LIKE 'Insert%'
        OR o.name LIKE 'Update%'
        OR o.name LIKE 'Delete%'
        OR o.name LIKE 'usp_xl_%'
        OR o.name LIKE 'usp_import_%'
        OR o.name LIKE 'usp_export_%'
        ))
    AND NOT (o.[type] = 'IF' AND (
           o.name LIKE 'Has%'
        OR o.name LIKE 'ufnExcelEvent%'
        OR o.name LIKE 'ufnParameterValues%'
        OR o.name LIKE 'ufn_xl_%'
        ))
UNION ALL
SELECT
    o.TABLE_SCHEMA
    , o.TABLE_NAME
    , o.TABLE_TYPE COLLATE Latin1_General_CI_AS
    , o.TABLE_CODE
    , o.INSERT_OBJECT AS INSERT_PROCEDURE
    , o.UPDATE_OBJECT AS UPDATE_PROCEDURE
    , o.DELETE_OBJECT AS DELETE_PROCEDURE
    , CAST(NULL AS nvarchar(50)) AS PROCEDURE_TYPE
FROM
    xls.[objects] o
WHERE
    o.TABLE_TYPE IN ('CODE', 'HTTP', 'TEXT')
    AND o.TABLE_SCHEMA IS NOT NULL
    AND o.TABLE_NAME IS NOT NULL
    AND o.TABLE_CODE IS NOT NULL


GO

UPDATE xls.handlers
SET 
    HANDLER_SCHEMA = TABLE_SCHEMA
    , HANDLER_NAME = 'MenuSeparator' + CAST(MENU_ORDER AS nvarchar(10))
WHERE
    HANDLER_TYPE = 'MENUSEPARATOR'
    AND HANDLER_NAME IS NULL;
GO

ALTER TABLE xls.handlers ALTER COLUMN TABLE_SCHEMA nvarchar(20) NULL;
ALTER TABLE xls.handlers ALTER COLUMN EVENT_NAME varchar(25) NULL;
ALTER TABLE xls.handlers ALTER COLUMN HANDLER_SCHEMA nvarchar(20) NULL;
ALTER TABLE xls.handlers ALTER COLUMN HANDLER_TYPE nvarchar(25) NULL;

ALTER TABLE xls.handlers ADD CONSTRAINT [IX_handlers_xls] UNIQUE ([TABLE_SCHEMA], [TABLE_NAME], [COLUMN_NAME], [EVENT_NAME], [HANDLER_SCHEMA], [HANDLER_NAME]);
GO
