-- =============================================
-- Application: Sample 17 - Budget Request
-- Version 10.8, January 9, 2023
--
-- Copyright 2019-2023 Gartle LLC
--
-- License: MIT
-- =============================================

SET NOCOUNT ON
GO

CREATE SCHEMA s17;
GO

CREATE TABLE [s17].[accounts] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_accounts] PRIMARY KEY ([id])
    , CONSTRAINT [IX_accounts_code] UNIQUE ([code])
    , CONSTRAINT [IX_accounts_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[categories] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_categories] PRIMARY KEY ([id])
    , CONSTRAINT [IX_categories_code] UNIQUE ([code])
    , CONSTRAINT [IX_categories_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[entities] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_entities] PRIMARY KEY ([id])
    , CONSTRAINT [IX_entities_code] UNIQUE ([code])
    , CONSTRAINT [IX_entities_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[products] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_products] PRIMARY KEY ([id])
    , CONSTRAINT [IX_products_code] UNIQUE ([code])
    , CONSTRAINT [IX_products_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[regions] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_regions] PRIMARY KEY ([id])
    , CONSTRAINT [IX_regions_code] UNIQUE ([code])
    , CONSTRAINT [IX_regions_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[subaccounts] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_subaccounts] PRIMARY KEY ([id])
    , CONSTRAINT [IX_subaccounts_code] UNIQUE ([code])
    , CONSTRAINT [IX_subaccounts_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[times] (
      [id] int IDENTITY(1,1) NOT NULL
    , [code] nvarchar(50) NOT NULL
    , [name] nvarchar(255) NOT NULL
    , [sort_order] int NULL
    , CONSTRAINT [PK_times] PRIMARY KEY ([id])
    , CONSTRAINT [IX_times_code] UNIQUE ([code])
    , CONSTRAINT [IX_times_name] UNIQUE ([name])
);
GO

CREATE TABLE [s17].[requests] (
      [id] int IDENTITY(1,1) NOT NULL
    , [entity_id] int NOT NULL
    , [category_id] int NOT NULL
    , [time_id] int NOT NULL
    , [row_index] int NOT NULL
    , [row_format] int NULL
    , [comment] nvarchar(255) NULL
    , [account_id] int NULL
    , [subaccount_id] int NULL
    , [product_id] int NULL
    , [region_id] int NULL
    , [total] float NULL
    , [01] float NULL
    , [02] float NULL
    , [03] float NULL
    , [04] float NULL
    , [05] float NULL
    , [06] float NULL
    , [07] float NULL
    , [08] float NULL
    , [09] float NULL
    , [10] float NULL
    , [11] float NULL
    , [12] float NULL
    , [row_formulas] nvarchar(max) NULL
    , [row_comments] nvarchar(max) NULL
    , [transaction_start_time] datetime NULL
    , [is_empty] AS (CONVERT([bit],case when [comment] IS NOT NULL OR [account_id] IS NOT NULL OR [subaccount_id] IS NOT NULL OR [product_id] IS NOT NULL OR [01] IS NOT NULL OR [02] IS NOT NULL OR [03] IS NOT NULL OR [04] IS NOT NULL OR [05] IS NOT NULL OR [06] IS NOT NULL OR [07] IS NOT NULL OR [08] IS NOT NULL OR [09] IS NOT NULL OR [10] IS NOT NULL OR [11] IS NOT NULL OR [12] IS NOT NULL then (0) else (1) end))
    , CONSTRAINT [PK_requests] PRIMARY KEY ([id])
    , CONSTRAINT [IX_requests] UNIQUE ([category_id], [time_id], [entity_id], [row_index])
);
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_accounts] FOREIGN KEY ([account_id]) REFERENCES [s17].[accounts] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_categories] FOREIGN KEY ([category_id]) REFERENCES [s17].[categories] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_entities] FOREIGN KEY ([entity_id]) REFERENCES [s17].[entities] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_products] FOREIGN KEY ([product_id]) REFERENCES [s17].[products] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_regions] FOREIGN KEY ([region_id]) REFERENCES [s17].[regions] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_subaccounts] FOREIGN KEY ([subaccount_id]) REFERENCES [s17].[subaccounts] ([id]) ON UPDATE CASCADE;
GO

ALTER TABLE [s17].[requests] ADD CONSTRAINT [FK_requests_times] FOREIGN KEY ([time_id]) REFERENCES [s17].[times] ([id]) ON UPDATE CASCADE;
GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects aggregate data from s17.requests
-- =============================================

CREATE PROCEDURE [s17].[usp_data]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    t.section + '.' + m3.code + COALESCE('.' + m4.code, '') + COALESCE('.' + m5.code, '') + COALESCE('.' + m6.code, '') + COALESCE('.' + m7.code, '') AS code
    , t.section
    , m1.code AS category
    , m2.code AS [time]
    , m3.code AS account
    , m3.name AS account_name
    , m4.code AS entity
    , m4.name AS entity_name
    , m5.code AS region
    , m5.name AS region_name
    , m6.code AS product
    , m6.name AS product_name
    , m7.code AS subaccount
    , m7.name AS subaccount_name
    , COALESCE([01], 0) + COALESCE([02], 0) + COALESCE([03], 0) + COALESCE([04], 0) + COALESCE([05], 0) + COALESCE([06], 0) + COALESCE([07], 0) + COALESCE([08], 0) + COALESCE([09], 0) + COALESCE([10], 0) + COALESCE([11], 0) + COALESCE([12], 0) AS total
    , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
FROM
    (
        SELECT
            'accounts' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , NULL AS product_id
            , NULL AS region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s17.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
        HAVING
            account_id IS NOT NULL
        UNION ALL
        SELECT
            'entities' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , t.entity_id
            , NULL AS product_id
            , NULL AS region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s17.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.entity_id
        HAVING
            entity_id IS NOT NULL
        UNION ALL
        SELECT
            'regions' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , NULL AS product_id
            , t.region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s17.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.region_id
        HAVING
            region_id IS NOT NULL
        UNION ALL
        SELECT
            'products' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , t.product_id
            , NULL AS region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s17.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.product_id
        HAVING
            product_id IS NOT NULL
        UNION ALL
        SELECT
            'region_products' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , t.product_id
            , t.region_id
            , NULL AS subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s17.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.region_id
            , t.product_id
        HAVING
            region_id IS NOT NULL
            AND product_id IS NOT NULL
        UNION ALL
        SELECT
            'subaccounts' AS section
            , t.category_id
            , t.time_id
            , t.account_id
            , NULL AS entity_id
            , NULL AS product_id
            , NULL AS region_id
            , t.subaccount_id
            , SUM(t.[01]) AS [01]
            , SUM(t.[02]) AS [02]
            , SUM(t.[03]) AS [03]
            , SUM(t.[04]) AS [04]
            , SUM(t.[05]) AS [05]
            , SUM(t.[06]) AS [06]
            , SUM(t.[07]) AS [07]
            , SUM(t.[08]) AS [08]
            , SUM(t.[09]) AS [09]
            , SUM(t.[10]) AS [10]
            , SUM(t.[11]) AS [11]
            , SUM(t.[12]) AS [12]
        FROM
            s17.requests t
        WHERE
            t.category_id = @category_id
            AND t.time_id = @time_id
            AND t.entity_id = COALESCE(@entity_id, t.entity_id)
        GROUP BY
            t.category_id
            , t.time_id
            , t.account_id
            , t.subaccount_id
        HAVING
            subaccount_id IS NOT NULL
    ) t
    INNER JOIN s17.categories m1 ON m1.id = t.category_id
    INNER JOIN s17.times m2 ON m2.id = t.time_id
    INNER JOIN s17.accounts m3 ON m3.id = t.account_id
    LEFT OUTER JOIN s17.entities m4 ON m4.id = t.entity_id
    LEFT OUTER JOIN s17.regions m5 ON m5.id = t.region_id
    LEFT OUTER JOIN s17.products m6 ON m6.id = t.product_id
    LEFT OUTER JOIN s17.subaccounts m7 ON m7.id = t.subaccount_id
ORDER BY
    code

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects data from s17.requests
-- =============================================

CREATE PROCEDURE [s17].[usp_request]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rows int = NULL
AS
BEGIN

SET NOCOUNT ON

IF @rows IS NULL SET @rows = 5

DECLARE @row_count int = COALESCE((
    SELECT
        MAX(t.row_index) AS row_index
    FROM
        s17.requests t
    WHERE
        t.entity_id = @entity_id
        AND t.category_id = @category_id
        AND t.time_id = @time_id
        AND t.is_empty = 0
    ), 0)

IF @row_count < @rows SET @row_count = @rows

;WITH e1(n) AS
(
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL
    SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1 UNION ALL SELECT 1
),                                              -- 10
e2(n) AS (SELECT 1 FROM e1 CROSS JOIN e1 AS b), -- 10*10
e3(n) AS (SELECT 1 FROM e1 CROSS JOIN e2)       -- 10*100

SELECT
    n.row_index
    , t.row_format
    , t.comment
    , t.account_id
    , t.subaccount_id
    , t.product_id
    , t.region_id
    , '=[@01]+[@02]+[@03]+[@04]+[@05]+[@06]+[@07]+[@08]+[@09]+[@10]+[@11]+[@12]' AS total
    , t.[01]
    , t.[02]
    , t.[03]
    , t.[04]
    , t.[05]
    , t.[06]
    , t.[07]
    , t.[08]
    , t.[09]
    , t.[10]
    , t.[11]
    , t.[12]
    , t.row_formulas
    , t.row_comments
FROM
    (SELECT ROW_NUMBER() OVER (ORDER BY n) AS row_index FROM e3) n
    LEFT OUTER JOIN s17.requests t ON
        t.row_index = n.row_index
        AND t.entity_id = @entity_id
        AND t.category_id = @category_id
        AND t.time_id = @time_id
WHERE
    n.row_index BETWEEN 1 AND @row_count
ORDER BY
    n.row_index

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure deleted data from s17.requests
-- =============================================

CREATE PROCEDURE [s17].[usp_request_delete]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

DELETE FROM s17.requests
WHERE
    entity_id = @entity_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @rownum
    AND transaction_start_time <= @transaction_start_time

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure updates data of s17.requests
-- =============================================

CREATE PROCEDURE [s17].[usp_request_update]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @comment nvarchar(255) = NULL
    , @account_id int = NULL
    , @subaccount_id int = NULL
    , @product_id int = NULL
    , @region_id int = NULL
    , @total float = NULL
    , @01 float = NULL, @02 float = NULL, @03 float = NULL, @04 float = NULL, @05 float = NULL, @06 float = NULL, @07 float = NULL, @08 float = NULL, @09 float = NULL, @10 float = NULL, @11 float = NULL, @12 float = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
    , @is_insert bit = NULL
AS
BEGIN

SET NOCOUNT ON

-- Delete the row at the old row_index if changed

IF COALESCE(@is_insert, 0) = 0
    DELETE FROM s17.requests
    WHERE
        entity_id = @entity_id
        AND category_id = @category_id
        AND time_id = @time_id
        AND row_index = @row_index
        AND NOT row_index = @rownum
        AND transaction_start_time < @transaction_start_time

-- Update the row completely at the new row_index

SET NOCOUNT OFF

UPDATE s17.requests
SET
    @row_index = @rownum
    , row_format = @row_format
    , comment = @comment
    , account_id = @account_id
    , subaccount_id = @subaccount_id
    , product_id = @product_id
    , region_id = @region_id
    , total = COALESCE(@01, 0) + COALESCE(@02, 0) + COALESCE(@03, 0) + COALESCE(@04, 0) + COALESCE(@05, 0) + COALESCE(@06, 0) + COALESCE(@07, 0) + COALESCE(@08, 0) + COALESCE(@09, 0) + COALESCE(@10, 0) + COALESCE(@11, 0) + COALESCE(@12, 0)
    , [01] = @01, [02] = @02, [03] = @03, [04] = @04, [05] = @05, [06] = @06, [07] = @07, [08] = @08, [09] = @09, [10] = @10, [11] = @11, [12] = @12
    , row_formulas = @row_formulas
    , row_comments = @row_comments
    , transaction_start_time = @transaction_start_time
WHERE
    entity_id = @entity_id
    AND category_id = @category_id
    AND time_id = @time_id
    AND row_index = @rownum

-- Insert a new non-empty row if the update command fails

IF @@ROWCOUNT = 0
    IF COALESCE(@is_insert, 0) = 1
        OR @comment IS NOT NULL
        OR @account_id IS NOT NULL
        OR @subaccount_id IS NOT NULL
        OR @product_id IS NOT NULL
        OR @region_id IS NOT NULL
        OR @01 IS NOT NULL OR @02 IS NOT NULL OR @03 IS NOT NULL OR @04 IS NOT NULL OR @05 IS NOT NULL OR @06 IS NOT NULL OR @07 IS NOT NULL OR @08 IS NOT NULL OR @09 IS NOT NULL OR @10 IS NOT NULL OR @11 IS NOT NULL OR @12 IS NOT NULL
INSERT INTO s17.requests
    ( entity_id
    , category_id
    , time_id
    , row_index
    , row_format
    , comment
    , account_id
    , subaccount_id
    , product_id
    , region_id
    , total
    , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
    , row_formulas
    , row_comments
    , transaction_start_time
    )
VALUES
    ( @entity_id
    , @category_id
    , @time_id
    , @rownum
    , @row_format
    , @comment
    , @account_id
    , @subaccount_id
    , @product_id
    , @region_id
    , COALESCE(@01, 0) + COALESCE(@02, 0) + COALESCE(@03, 0) + COALESCE(@04, 0) + COALESCE(@05, 0) + COALESCE(@06, 0) + COALESCE(@07, 0) + COALESCE(@08, 0) + COALESCE(@09, 0) + COALESCE(@10, 0) + COALESCE(@11, 0) + COALESCE(@12, 0)
    , @01, @02, @03, @04, @05, @06, @07, @08, @09, @10, @11, @12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    )

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure inserts data into s17.requests
-- =============================================

CREATE PROCEDURE [s17].[usp_request_insert]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @rownum int = NULL
    , @row_index int = NULL
    , @row_format int = NULL
    , @comment nvarchar(255) = NULL
    , @account_id int = NULL
    , @subaccount_id int = NULL
    , @product_id int = NULL
    , @region_id int = NULL
    , @total float = NULL
    , @01 float = NULL, @02 float = NULL, @03 float = NULL, @04 float = NULL, @05 float = NULL, @06 float = NULL, @07 float = NULL, @08 float = NULL, @09 float = NULL, @10 float = NULL, @11 float = NULL, @12 float = NULL
    , @row_formulas nvarchar(max) = NULL
    , @row_comments nvarchar(max) = NULL
    , @transaction_start_time datetime = NULL
AS
BEGIN

EXEC s17.usp_request_update
    @category_id
    , @time_id
    , @entity_id
    , @rownum
    , @row_index
    , @row_format
    , @comment
    , @account_id
    , @subaccount_id
    , @product_id
    , @region_id
    , @total
    , @01, @02, @03, @04, @05, @06, @07, @08, @09, @10, @11, @12
    , @row_formulas
    , @row_comments
    , @transaction_start_time
    , 1

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure selects all requests
-- =============================================

CREATE PROCEDURE [s17].[usp_requests]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
AS
BEGIN

SET NOCOUNT ON

SELECT
    r.category_id
    , r.time_id
    , r.entity_id
    , MAX(m1.name) AS category
    , MAX(m2.name) AS [time]
    , MAX(m3.name) AS entity
    , MAX(r.transaction_start_time) AS last_update
FROM
    s17.requests r
    INNER JOIN s17.categories m1 ON m1.id = r.category_id
    INNER JOIN s17.times m2 ON m2.id = r.time_id
    INNER JOIN s17.entities m3 ON m3.id = r.entity_id
WHERE
    r.category_id = COALESCE(@category_id, r.category_id)
    AND r.time_id = COALESCE(@time_id, r.time_id)
    AND r.entity_id = COALESCE(@entity_id, r.entity_id)
GROUP BY
    r.category_id
    , r.time_id
    , r.entity_id

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure cleans the request data
-- =============================================

CREATE PROCEDURE [s17].[xl_actions_clean_requests]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @set_1_to_delete tinyint = NULL
AS
BEGIN

DECLARE @message nvarchar(max)

IF NOT COALESCE(@set_1_to_delete, 0) = 1
    BEGIN
    SET @message = 'Set 1 in the parameter to delete data'
    RAISERROR (@message, 11, 0)
    RETURN
    END

DELETE FROM s17.requests
WHERE
    category_id = @category_id
    AND [time_id] = @time_id
    AND [entity_id] = COALESCE(@entity_id, [entity_id])

END


GO

-- =============================================
-- Author:      Gartle LLC
-- Release:     10.0, 2022-07-05
-- Description: The procedure clones the request data
-- =============================================

CREATE PROCEDURE [s17].[xl_actions_clone_requests]
    @category_id int = NULL
    , @time_id int = NULL
    , @entity_id int = NULL
    , @target_category_id int = NULL
    , @target_time_id int = NULL
    , @target_entity_id int = NULL
    , @set_1_to_copy tinyint = NULL
AS
BEGIN

SET NOCOUNT ON

DECLARE @message nvarchar(max)

IF NOT COALESCE(@set_1_to_copy, 0) = 1
    BEGIN
    SET @message = 'Set 1 in the parameter to copy data'
    RAISERROR (@message, 11, 0)
    RETURN
    END

BEGIN TRANSACTION

BEGIN TRY

    INSERT INTO s17.requests
        ( entity_id
        , category_id
        , time_id
        , row_index
        , row_format
        , comment
        , account_id
        , subaccount_id
        , product_id
        , region_id
        , total
        , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
        , row_formulas
        , transaction_start_time
        )
    SELECT
        COALESCE(@target_entity_id, f.entity_id)
        , @target_category_id
        , @target_time_id
        , row_index
        , row_format
        , comment
        , account_id
        , subaccount_id
        , product_id
        , region_id
        , total
        , [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12]
        , row_formulas
        , transaction_start_time
    FROM
        s17.requests f
    WHERE
        f.category_id = @category_id
        AND f.time_id = @time_id
        AND f.entity_id = COALESCE(@entity_id, f.entity_id)

END TRY

BEGIN CATCH
    SELECT @message = ERROR_MESSAGE()

    IF @@TRANCOUNT > 0
        ROLLBACK TRANSACTION

    RAISERROR (@message, 11, 0, @message)
    RETURN

END CATCH

IF @@TRANCOUNT > 0
    COMMIT TRANSACTION

END


GO

SET IDENTITY_INSERT [s17].[accounts] ON;
INSERT INTO [s17].[accounts] ([id], [code], [name], [sort_order]) VALUES (1, N'100', N'Revenue', 1);
INSERT INTO [s17].[accounts] ([id], [code], [name], [sort_order]) VALUES (2, N'200', N'Expenses', 2);
INSERT INTO [s17].[accounts] ([id], [code], [name], [sort_order]) VALUES (3, N'300', N'Payroll', 3);
INSERT INTO [s17].[accounts] ([id], [code], [name], [sort_order]) VALUES (4, N'400', N'Taxes', 4);
SET IDENTITY_INSERT [s17].[accounts] OFF;
GO

SET IDENTITY_INSERT [s17].[categories] ON;
INSERT INTO [s17].[categories] ([id], [code], [name], [sort_order]) VALUES (1, N'BUDGET', N'Budget', 1);
INSERT INTO [s17].[categories] ([id], [code], [name], [sort_order]) VALUES (2, N'ACTUAL', N'Actual', 2);
INSERT INTO [s17].[categories] ([id], [code], [name], [sort_order]) VALUES (3, N'FORECAST', N'Forecast', 3);
SET IDENTITY_INSERT [s17].[categories] OFF;
GO

SET IDENTITY_INSERT [s17].[entities] ON;
INSERT INTO [s17].[entities] ([id], [code], [name], [sort_order]) VALUES (1, N'E101', N'Entity 101', 1);
INSERT INTO [s17].[entities] ([id], [code], [name], [sort_order]) VALUES (2, N'E201', N'Entity 201', 2);
INSERT INTO [s17].[entities] ([id], [code], [name], [sort_order]) VALUES (3, N'E301', N'Entity 301', 3);
INSERT INTO [s17].[entities] ([id], [code], [name], [sort_order]) VALUES (4, N'E401', N'Entity 401', 4);
SET IDENTITY_INSERT [s17].[entities] OFF;
GO

SET IDENTITY_INSERT [s17].[products] ON;
INSERT INTO [s17].[products] ([id], [code], [name], [sort_order]) VALUES (1, N'P01', N'Product P1', 1);
INSERT INTO [s17].[products] ([id], [code], [name], [sort_order]) VALUES (2, N'P02', N'Product P2', 2);
INSERT INTO [s17].[products] ([id], [code], [name], [sort_order]) VALUES (3, N'P03', N'Product P3', 3);
INSERT INTO [s17].[products] ([id], [code], [name], [sort_order]) VALUES (4, N'P04', N'Product P4', 4);
INSERT INTO [s17].[products] ([id], [code], [name], [sort_order]) VALUES (5, N'P05', N'Product P5', 5);
SET IDENTITY_INSERT [s17].[products] OFF;
GO

SET IDENTITY_INSERT [s17].[regions] ON;
INSERT INTO [s17].[regions] ([id], [code], [name], [sort_order]) VALUES (1, N'US', N'USA', 1);
INSERT INTO [s17].[regions] ([id], [code], [name], [sort_order]) VALUES (2, N'CA', N'Canada', 2);
INSERT INTO [s17].[regions] ([id], [code], [name], [sort_order]) VALUES (3, N'UK', N'UK', 3);
INSERT INTO [s17].[regions] ([id], [code], [name], [sort_order]) VALUES (4, N'DE', N'Germany', 4);
INSERT INTO [s17].[regions] ([id], [code], [name], [sort_order]) VALUES (5, N'FR', N'France', 5);
SET IDENTITY_INSERT [s17].[regions] OFF;
GO

SET IDENTITY_INSERT [s17].[subaccounts] ON;
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (1, N'C01', N'Customer C1', 1);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (2, N'C02', N'Customer C2', 2);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (3, N'C03', N'Customer C3', 3);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (4, N'C04', N'Customer C4', 4);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (5, N'C05', N'Customer C5', 5);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (6, N'C06', N'Customer C6', 6);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (7, N'C07', N'Customer C7', 7);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (8, N'S01', N'Supplier S1', 8);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (9, N'S02', N'Supplier S2', 9);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (10, N'S03', N'Supplier S3', 10);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (11, N'S04', N'Supplier S4', 11);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (12, N'S05', N'Supplier S5', 12);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (13, N'S06', N'Supplier S6', 13);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (14, N'S07', N'Supplier S7', 14);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (15, N'T01', N'Corporate Income Tax', 15);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (16, N'T02', N'Individual Income Tax', 16);
INSERT INTO [s17].[subaccounts] ([id], [code], [name], [sort_order]) VALUES (17, N'T03', N'Payroll Taxes', 17);
SET IDENTITY_INSERT [s17].[subaccounts] OFF;
GO

SET IDENTITY_INSERT [s17].[times] ON;
INSERT INTO [s17].[times] ([id], [code], [name], [sort_order]) VALUES (1, N'2022', N'2022', 1);
INSERT INTO [s17].[times] ([id], [code], [name], [sort_order]) VALUES (2, N'2023', N'2023', 2);
INSERT INTO [s17].[times] ([id], [code], [name], [sort_order]) VALUES (3, N'2024', N'2024', 3);
SET IDENTITY_INSERT [s17].[times] OFF;
GO

SET IDENTITY_INSERT [s17].[requests] ON;
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (1, 1, 1, 1, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 7200000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, 600000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (2, 1, 1, 1, 3, NULL, NULL, 1, 1, 1, 1, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (3, 1, 1, 1, 4, NULL, NULL, 1, 2, 2, 1, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (4, 1, 1, 1, 5, NULL, NULL, 1, 3, 1, 2, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (5, 1, 1, 1, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (6, 1, 1, 1, 8, NULL, NULL, 2, 8, 1, 1, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (7, 1, 1, 1, 9, NULL, NULL, 2, 9, 2, 1, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (8, 1, 1, 1, 10, NULL, NULL, 2, 8, 1, 2, 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (9, 1, 1, 1, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 18:55:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (10, 2, 1, 1, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (11, 2, 1, 1, 3, NULL, NULL, 1, 4, 2, 3, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (12, 2, 1, 1, 4, NULL, NULL, 1, 5, 3, 4, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (13, 2, 1, 1, 5, NULL, NULL, 1, 6, 3, 5, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (14, 2, 1, 1, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (15, 2, 1, 1, 8, NULL, NULL, 2, 10, 2, 3, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (16, 2, 1, 1, 9, NULL, NULL, 2, 11, 3, 4, 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (17, 2, 1, 1, 10, NULL, NULL, 2, 11, 3, 5, 600000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, 50000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (18, 2, 1, 1, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 18:57:21.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (19, 3, 1, 1, 2, 1, NULL, 3, NULL, NULL, 1, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (20, 3, 1, 1, 3, NULL, NULL, 4, 16, NULL, 1, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (21, 3, 1, 1, 4, NULL, NULL, 4, 17, NULL, 1, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (22, 3, 1, 1, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (23, 3, 1, 1, 6, 1, NULL, 3, NULL, NULL, 3, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (24, 3, 1, 1, 7, NULL, NULL, 4, 16, NULL, 3, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (25, 3, 1, 1, 8, NULL, NULL, 4, 17, NULL, 3, 180000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, 15000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 18:57:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (26, 3, 1, 1, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (27, 3, 1, 1, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (28, 4, 1, 1, 2, 1, NULL, 4, 15, NULL, NULL, 1512000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, NULL, NULL, '20210807 19:42:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (29, 1, 2, 1, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 7920000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, 660000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (30, 1, 2, 1, 3, NULL, NULL, 1, 1, 1, 1, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (31, 1, 2, 1, 4, NULL, NULL, 1, 2, 2, 1, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (32, 1, 2, 1, 5, NULL, NULL, 1, 3, 1, 2, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (33, 1, 2, 1, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (34, 1, 2, 1, 8, NULL, NULL, 2, 8, 1, 1, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (35, 1, 2, 1, 9, NULL, NULL, 2, 9, 2, 1, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (36, 1, 2, 1, 10, NULL, NULL, 2, 8, 1, 2, 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (37, 1, 2, 1, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 4620000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:13:43.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (38, 2, 2, 1, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (39, 2, 2, 1, 3, NULL, NULL, 1, 4, 2, 3, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (40, 2, 2, 1, 4, NULL, NULL, 1, 5, 3, 4, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (41, 2, 2, 1, 5, NULL, NULL, 1, 6, 3, 5, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (42, 2, 2, 1, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (43, 2, 2, 1, 8, NULL, NULL, 2, 10, 2, 3, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (44, 2, 2, 1, 9, NULL, NULL, 2, 11, 3, 4, 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (45, 2, 2, 1, 10, NULL, NULL, 2, 11, 3, 5, 660000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, 55000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (46, 2, 2, 1, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:09:09.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (47, 3, 2, 1, 2, 1, NULL, 3, NULL, NULL, 1, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (48, 3, 2, 1, 3, NULL, NULL, 4, 16, NULL, 1, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (49, 3, 2, 1, 4, NULL, NULL, 4, 17, NULL, 1, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (50, 3, 2, 1, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (51, 3, 2, 1, 6, 1, NULL, 3, NULL, NULL, 3, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (52, 3, 2, 1, 7, NULL, NULL, 4, 16, NULL, 3, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (53, 3, 2, 1, 8, NULL, NULL, 4, 17, NULL, 3, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:05:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (54, 3, 2, 1, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (55, 3, 2, 1, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (56, 4, 2, 1, 2, 1, NULL, 4, 15, NULL, NULL, 1512000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, 126000, NULL, NULL, '20210807 18:59:33.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (57, 1, 3, 1, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 7560000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, 630000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (58, 1, 3, 1, 3, NULL, NULL, 1, 1, 1, 1, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (59, 1, 3, 1, 4, NULL, NULL, 1, 2, 2, 1, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (60, 1, 3, 1, 5, NULL, NULL, 1, 3, 1, 2, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (61, 1, 3, 1, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 3360000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, 280000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (62, 1, 3, 1, 8, NULL, NULL, 2, 8, 1, 1, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (63, 1, 3, 1, 9, NULL, NULL, 2, 9, 2, 1, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (64, 1, 3, 1, 10, NULL, NULL, 2, 8, 1, 2, 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:16:42.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (65, 1, 3, 1, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (66, 2, 3, 1, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 6360000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, 530000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (67, 2, 3, 1, 3, NULL, NULL, 1, 4, 2, 3, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (68, 2, 3, 1, 4, NULL, NULL, 1, 5, 3, 4, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (69, 2, 3, 1, 5, NULL, NULL, 1, 6, 3, 5, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (70, 2, 3, 1, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 2760000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, 230000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (71, 2, 3, 1, 8, NULL, NULL, 2, 10, 2, 3, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (72, 2, 3, 1, 9, NULL, NULL, 2, 11, 3, 4, 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (73, 2, 3, 1, 10, NULL, NULL, 2, 11, 3, 5, 720000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, 60000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (74, 2, 3, 1, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (75, 3, 3, 1, 2, 1, NULL, 3, NULL, NULL, 1, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (76, 3, 3, 1, 3, NULL, NULL, 4, 16, NULL, 1, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (77, 3, 3, 1, 4, NULL, NULL, 4, 17, NULL, 1, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (78, 3, 3, 1, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (79, 3, 3, 1, 6, 1, NULL, 3, NULL, NULL, 3, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (80, 3, 3, 1, 7, NULL, NULL, 4, 16, NULL, 3, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (81, 3, 3, 1, 8, NULL, NULL, 4, 17, NULL, 3, 198000, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, 16500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:18:35.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (82, 3, 3, 1, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (83, 3, 3, 1, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (84, 4, 3, 1, 2, 1, NULL, 4, 15, NULL, NULL, 1429200, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, 119100, NULL, NULL, '20210807 19:19:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (85, 1, 1, 2, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 10800000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, 900000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (86, 1, 1, 2, 3, NULL, NULL, 1, 1, 1, 1, 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (87, 1, 1, 2, 4, NULL, NULL, 1, 2, 2, 1, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (88, 1, 1, 2, 5, NULL, NULL, 1, 3, 1, 2, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (89, 1, 1, 2, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 5100000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, 425000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (90, 1, 1, 2, 8, NULL, NULL, 2, 8, 1, 1, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (91, 1, 1, 2, 9, NULL, NULL, 2, 9, 2, 1, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (92, 1, 1, 2, 10, NULL, NULL, 2, 8, 1, 2, 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (93, 1, 1, 2, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5700000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, 475000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 18:56:14.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (94, 2, 1, 2, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 9600000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, 800000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (95, 2, 1, 2, 3, NULL, NULL, 1, 4, 2, 3, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (96, 2, 1, 2, 4, NULL, NULL, 1, 5, 3, 4, 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (97, 2, 1, 2, 5, NULL, NULL, 1, 6, 3, 5, 3000000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, 250000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (98, 2, 1, 2, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (99, 2, 1, 2, 8, NULL, NULL, 2, 10, 2, 3, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (100, 2, 1, 2, 9, NULL, NULL, 2, 11, 3, 4, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (101, 2, 1, 2, 10, NULL, NULL, 2, 11, 3, 5, 1200000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, 100000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (102, 2, 1, 2, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 18:57:06.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (103, 3, 1, 2, 2, 1, NULL, 3, NULL, NULL, 1, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (104, 3, 1, 2, 3, NULL, NULL, 4, 16, NULL, 1, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (105, 3, 1, 2, 4, NULL, NULL, 4, 17, NULL, 1, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (106, 3, 1, 2, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (107, 3, 1, 2, 6, 1, NULL, 3, NULL, NULL, 3, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (108, 3, 1, 2, 7, NULL, NULL, 4, 16, NULL, 3, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (109, 3, 1, 2, 8, NULL, NULL, 4, 17, NULL, 3, 360000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, 30000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 18:57:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (110, 3, 1, 2, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (111, 3, 1, 2, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (112, 4, 1, 2, 2, 1, NULL, 4, 15, NULL, NULL, 1674000, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, 139500, NULL, NULL, '20210807 19:42:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (113, 1, 3, 2, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 11160000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, 930000, N'{"02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (114, 1, 3, 2, 3, NULL, NULL, 1, 1, 1, 1, 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (115, 1, 3, 2, 4, NULL, NULL, 1, 2, 2, 1, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (116, 1, 3, 2, 5, NULL, NULL, 1, 3, 1, 2, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (117, 1, 3, 2, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 5340000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, 445000, N'{"02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (118, 1, 3, 2, 8, NULL, NULL, 2, 8, 1, 1, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (119, 1, 3, 2, 9, NULL, NULL, 2, 9, 2, 1, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (120, 1, 3, 2, 10, NULL, NULL, 2, 8, 1, 2, 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (121, 1, 3, 2, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5820000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, 485000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:17:02.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (122, 2, 3, 2, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 9960000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, 830000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (123, 2, 3, 2, 3, NULL, NULL, 1, 4, 2, 3, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (124, 2, 3, 2, 4, NULL, NULL, 1, 5, 3, 4, 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (125, 2, 3, 2, 5, NULL, NULL, 1, 6, 3, 5, 3120000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, 260000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (126, 2, 3, 2, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 4560000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, 380000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (127, 2, 3, 2, 8, NULL, NULL, 2, 10, 2, 3, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (128, 2, 3, 2, 9, NULL, NULL, 2, 11, 3, 4, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (129, 2, 3, 2, 10, NULL, NULL, 2, 11, 3, 5, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (130, 2, 3, 2, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5400000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, 450000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:17:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (131, 3, 3, 2, 2, 1, NULL, 3, NULL, NULL, 1, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (132, 3, 3, 2, 3, NULL, NULL, 4, 16, NULL, 1, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (133, 3, 3, 2, 4, NULL, NULL, 4, 17, NULL, 1, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (134, 3, 3, 2, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (135, 3, 3, 2, 6, 1, NULL, 3, NULL, NULL, 3, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (136, 3, 3, 2, 7, NULL, NULL, 4, 16, NULL, 3, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (137, 3, 3, 2, 8, NULL, NULL, 4, 17, NULL, 3, 378000, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, 31500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:18:48.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (138, 3, 3, 2, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (139, 3, 3, 2, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (140, 4, 3, 2, 2, 1, NULL, 4, 15, NULL, NULL, 1627200, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, 135600, NULL, NULL, '20210807 19:19:40.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (141, 1, 1, 3, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 14400000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, 1200000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (142, 1, 1, 3, 3, NULL, NULL, 1, 1, 1, 1, 6000000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, 500000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (143, 1, 1, 3, 4, NULL, NULL, 1, 2, 2, 1, 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (144, 1, 1, 3, 5, NULL, NULL, 1, 3, 1, 2, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (145, 1, 1, 3, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (146, 1, 1, 3, 8, NULL, NULL, 2, 8, 1, 1, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (147, 1, 1, 3, 9, NULL, NULL, 2, 9, 2, 1, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (148, 1, 1, 3, 10, NULL, NULL, 2, 8, 1, 2, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210811 19:10:52.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (149, 1, 1, 3, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 18:56:41.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (150, 2, 1, 3, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 13200000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, 1100000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (151, 2, 1, 3, 3, NULL, NULL, 1, 4, 2, 3, 4800000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, 400000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (152, 2, 1, 3, 4, NULL, NULL, 1, 5, 3, 4, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (153, 2, 1, 3, 5, NULL, NULL, 1, 6, 3, 5, 4200000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, 350000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (154, 2, 1, 3, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (155, 2, 1, 3, 8, NULL, NULL, 2, 10, 2, 3, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (156, 2, 1, 3, 9, NULL, NULL, 2, 11, 3, 4, 2400000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, 200000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (157, 2, 1, 3, 10, NULL, NULL, 2, 11, 3, 5, 1800000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, 150000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (158, 2, 1, 3, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 18:56:54.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (159, 3, 1, 3, 2, 1, NULL, 3, NULL, NULL, 1, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (160, 3, 1, 3, 3, NULL, NULL, 4, 16, NULL, 1, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (161, 3, 1, 3, 4, NULL, NULL, 4, 17, NULL, 1, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (162, 3, 1, 3, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (163, 3, 1, 3, 6, 1, NULL, 3, NULL, NULL, 3, 3600000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, 300000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (164, 3, 1, 3, 7, NULL, NULL, 4, 16, NULL, 3, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (165, 3, 1, 3, 8, NULL, NULL, 4, 17, NULL, 3, 540000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, 45000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 18:58:08.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (166, 3, 1, 3, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (167, 3, 1, 3, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (168, 4, 1, 3, 2, 1, NULL, 4, 15, NULL, NULL, 1836000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, 153000, NULL, NULL, '20210807 18:58:50.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (169, 1, 3, 3, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 14760000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, 1230000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (170, 1, 3, 3, 3, NULL, NULL, 1, 1, 1, 1, 6120000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, 510000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (171, 1, 3, 3, 4, NULL, NULL, 1, 2, 2, 1, 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (172, 1, 3, 3, 5, NULL, NULL, 1, 3, 1, 2, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (173, 1, 3, 3, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6960000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (174, 1, 3, 3, 8, NULL, NULL, 2, 8, 1, 1, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (175, 1, 3, 3, 9, NULL, NULL, 2, 9, 2, 1, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (176, 1, 3, 3, 10, NULL, NULL, 2, 8, 1, 2, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (177, 1, 3, 3, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 7800000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, 650000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:17:23.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (178, 2, 3, 3, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 13560000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, 1130000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (179, 2, 3, 3, 3, NULL, NULL, 1, 4, 2, 3, 4920000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, 410000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (180, 2, 3, 3, 4, NULL, NULL, 1, 5, 3, 4, 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (181, 2, 3, 3, 5, NULL, NULL, 1, 6, 3, 5, 4320000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, 360000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (182, 2, 3, 3, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 6960000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, 580000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (183, 2, 3, 3, 8, NULL, NULL, 2, 10, 2, 3, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (184, 2, 3, 3, 9, NULL, NULL, 2, 11, 3, 4, 2520000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, 210000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (185, 2, 3, 3, 10, NULL, NULL, 2, 11, 3, 5, 1920000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, 160000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (186, 2, 3, 3, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 6600000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, 550000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:17:39.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (187, 3, 3, 3, 2, 1, NULL, 3, NULL, NULL, 1, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (188, 3, 3, 3, 3, NULL, NULL, 4, 16, NULL, 1, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (189, 3, 3, 3, 4, NULL, NULL, 4, 17, NULL, 1, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (190, 3, 3, 3, 5, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (191, 3, 3, 3, 6, 1, NULL, 3, NULL, NULL, 3, 3720000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, 310000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (192, 3, 3, 3, 7, NULL, NULL, 4, 16, NULL, 3, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (193, 3, 3, 3, 8, NULL, NULL, 4, 17, NULL, 3, 558000, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, 46500, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:18:57.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (194, 3, 3, 3, 9, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (195, 3, 3, 3, 10, NULL, NULL, NULL, NULL, NULL, NULL, 0, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, NULL, '20200117 09:05:00.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (196, 4, 3, 3, 2, 1, NULL, 4, 15, NULL, NULL, 1753200, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, 146100, NULL, NULL, '20210807 19:19:22.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (197, 4, 2, 2, 2, 1, NULL, 4, 15, NULL, NULL, 1886400, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, 157200, NULL, NULL, '20210807 19:03:13.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (198, 3, 2, 2, 2, 1, NULL, 3, NULL, NULL, 1, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:07:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (199, 3, 2, 2, 3, NULL, NULL, 4, 16, NULL, 1, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:07:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (200, 3, 2, 2, 4, NULL, NULL, 4, 17, NULL, 1, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:07:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (201, 3, 2, 2, 6, 1, NULL, 3, NULL, NULL, 3, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:07:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (202, 3, 2, 2, 7, NULL, NULL, 4, 16, NULL, 3, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-1]C*0.15","02":"=R[-1]C*0.15","03":"=R[-1]C*0.15","04":"=R[-1]C*0.15","05":"=R[-1]C*0.15","06":"=R[-1]C*0.15","07":"=R[-1]C*0.15","08":"=R[-1]C*0.15","09":"=R[-1]C*0.15","10":"=R[-1]C*0.15","11":"=R[-1]C*0.15","12":"=R[-1]C*0.15"}', NULL, '20210807 19:07:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (203, 3, 2, 2, 8, NULL, NULL, 4, 17, NULL, 3, 396000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, 33000, N'{"01":"=R[-2]C*0.15","02":"=R[-2]C*0.15","03":"=R[-2]C*0.15","04":"=R[-2]C*0.15","05":"=R[-2]C*0.15","06":"=R[-2]C*0.15","07":"=R[-2]C*0.15","08":"=R[-2]C*0.15","09":"=R[-2]C*0.15","10":"=R[-2]C*0.15","11":"=R[-2]C*0.15","12":"=R[-2]C*0.15"}', NULL, '20210807 19:07:10.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (204, 2, 2, 2, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 10560000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, 880000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (205, 2, 2, 2, 3, NULL, NULL, 1, 4, 2, 3, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (206, 2, 2, 2, 4, NULL, NULL, 1, 5, 3, 4, 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (207, 2, 2, 2, 5, NULL, NULL, 1, 6, 3, 5, 3300000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, 275000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (208, 2, 2, 2, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 4620000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, 385000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (209, 2, 2, 2, 8, NULL, NULL, 2, 10, 2, 3, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (210, 2, 2, 2, 9, NULL, NULL, 2, 11, 3, 4, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (211, 2, 2, 2, 10, NULL, NULL, 2, 11, 3, 5, 1320000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, 110000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (212, 2, 2, 2, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 5940000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, 495000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:08:38.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (213, 1, 2, 2, 2, 1, N'Revenue', NULL, NULL, NULL, NULL, 11880000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, 990000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (214, 1, 2, 2, 3, NULL, NULL, 1, 1, 1, 1, 5280000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, 440000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (215, 1, 2, 2, 4, NULL, NULL, 1, 2, 2, 1, 3960000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, 330000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (216, 1, 2, 2, 5, NULL, NULL, 1, 3, 1, 2, 2640000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, 220000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (217, 1, 2, 2, 7, 1, N'Expenses', NULL, NULL, NULL, NULL, 5460000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, 455000, N'{"01":"=SUM(R[1]C:R[3]C)","02":"=SUM(R[1]C:R[3]C)","03":"=SUM(R[1]C:R[3]C)","04":"=SUM(R[1]C:R[3]C)","05":"=SUM(R[1]C:R[3]C)","06":"=SUM(R[1]C:R[3]C)","07":"=SUM(R[1]C:R[3]C)","08":"=SUM(R[1]C:R[3]C)","09":"=SUM(R[1]C:R[3]C)","10":"=SUM(R[1]C:R[3]C)","11":"=SUM(R[1]C:R[3]C)","12":"=SUM(R[1]C:R[3]C)"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (218, 1, 2, 2, 8, NULL, NULL, 2, 8, 1, 1, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (219, 1, 2, 2, 9, NULL, NULL, 2, 9, 2, 1, 1980000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, 165000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (220, 1, 2, 2, 10, NULL, NULL, 2, 8, 1, 2, 1500000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, 125000, N'{"02":"=[@01]","03":"=[@02]","04":"=[@03]","05":"=[@04]","06":"=[@05]","07":"=[@06]","08":"=[@07]","09":"=[@08]","10":"=[@09]","11":"=[@10]","12":"=[@11]"}', NULL, '20210807 19:09:53.000');
INSERT INTO [s17].[requests] ([id], [entity_id], [category_id], [time_id], [row_index], [row_format], [comment], [account_id], [subaccount_id], [product_id], [region_id], [total], [01], [02], [03], [04], [05], [06], [07], [08], [09], [10], [11], [12], [row_formulas], [row_comments], [transaction_start_time]) VALUES (221, 1, 2, 2, 12, 1, N'Margin Profit', NULL, NULL, NULL, NULL, 6420000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, 535000, N'{"01":"=R[-10]C-R[-5]C","02":"=R[-10]C-R[-5]C","03":"=R[-10]C-R[-5]C","04":"=R[-10]C-R[-5]C","05":"=R[-10]C-R[-5]C","06":"=R[-10]C-R[-5]C","07":"=R[-10]C-R[-5]C","08":"=R[-10]C-R[-5]C","09":"=R[-10]C-R[-5]C","10":"=R[-10]C-R[-5]C","11":"=R[-10]C-R[-5]C","12":"=R[-10]C-R[-5]C"}', NULL, '20210807 19:09:53.000');
SET IDENTITY_INSERT [s17].[requests] OFF;
GO

INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'accounts', N'<table name="s17.accounts"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="sort_order" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="FormatConditions(1).ColumnsCount" value="2" type="Double" /><column name="code" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$E$7" type="String" /><column name="code" property="FormatConditions(1).Type" value="2" type="Double" /><column name="code" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="code" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String" /><column name="code" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'categories', N'<table name="s17.categories"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="sort_order" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$D$6" type="String" /><column name="code" property="FormatConditions(1).Type" value="2" type="Double" /><column name="code" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="code" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String" /><column name="code" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="name" property="FormatConditions(1).AppliesTo.Address" value="$E$4:$E$6" type="String" /><column name="name" property="FormatConditions(1).Type" value="2" type="Double" /><column name="name" property="FormatConditions(1).Priority" value="2" type="Double" /><column name="name" property="FormatConditions(1).Formula1" value="=ISBLANK(E4)" type="String" /><column name="name" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="2" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="2" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'entities', N'<table name="s17.entities"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="sort_order" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="FormatConditions(1).ColumnsCount" value="2" type="Double" /><column name="code" property="FormatConditions(1).AppliesTo.Address" value="$D$4:$E$7" type="String" /><column name="code" property="FormatConditions(1).Type" value="2" type="Double" /><column name="code" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="code" property="FormatConditions(1).Formula1" value="=ISBLANK(D4)" type="String" /><column name="code" property="FormatConditions(1).Interior.Color" value="65535" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'products', N'<table name="s17.products"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'regions', N'<table name="s17.regions"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="sort_order" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'subaccounts', N'<table name="s17.subaccounts"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'times', N'<table name="s17.times"><columnFormats><column name="" property="ListObjectName" value="members" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="id" property="Address" value="$C$4" type="String" /><column name="id" property="ColumnWidth" value="4.29" type="Double" /><column name="id" property="NumberFormat" value="General" type="String" /><column name="id" property="Validation.Type" value="1" type="Double" /><column name="id" property="Validation.Operator" value="1" type="Double" /><column name="id" property="Validation.Formula1" value="-2147483648" type="String" /><column name="id" property="Validation.Formula2" value="2147483647" type="String" /><column name="id" property="Validation.AlertStyle" value="1" type="Double" /><column name="id" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="id" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="id" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="id" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="id" property="Validation.ShowInput" value="True" type="Boolean" /><column name="id" property="Validation.ShowError" value="True" type="Boolean" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$D$4" type="String" /><column name="code" property="ColumnWidth" value="13.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="code" property="Validation.Type" value="6" type="Double" /><column name="code" property="Validation.Operator" value="8" type="Double" /><column name="code" property="Validation.Formula1" value="50" type="String" /><column name="code" property="Validation.AlertStyle" value="1" type="Double" /><column name="code" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="code" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="code" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="code" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(50) datatype." type="String" /><column name="code" property="Validation.ShowInput" value="True" type="Boolean" /><column name="code" property="Validation.ShowError" value="True" type="Boolean" /><column name="name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="name" property="Address" value="$E$4" type="String" /><column name="name" property="ColumnWidth" value="33.57" type="Double" /><column name="name" property="NumberFormat" value="General" type="String" /><column name="name" property="Validation.Type" value="6" type="Double" /><column name="name" property="Validation.Operator" value="8" type="Double" /><column name="name" property="Validation.Formula1" value="255" type="String" /><column name="name" property="Validation.AlertStyle" value="1" type="Double" /><column name="name" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="name" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="name" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="name" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="name" property="Validation.ShowInput" value="True" type="Boolean" /><column name="name" property="Validation.ShowError" value="True" type="Boolean" /><column name="sort_order" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="sort_order" property="Address" value="$F$4" type="String" /><column name="sort_order" property="ColumnWidth" value="11.86" type="Double" /><column name="sort_order" property="NumberFormat" value="General" type="String" /><column name="sort_order" property="Validation.Type" value="1" type="Double" /><column name="sort_order" property="Validation.Operator" value="1" type="Double" /><column name="sort_order" property="Validation.Formula1" value="-2147483648" type="String" /><column name="sort_order" property="Validation.Formula2" value="2147483647" type="String" /><column name="sort_order" property="Validation.AlertStyle" value="1" type="Double" /><column name="sort_order" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="sort_order" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="sort_order" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="sort_order" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="sort_order" property="Validation.ShowInput" value="True" type="Boolean" /><column name="sort_order" property="Validation.ShowError" value="True" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="sort_order" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="SortFields(2)" property="KeyfieldName" value="code" type="String" /><column name="SortFields(2)" property="SortOn" value="0" type="Double" /><column name="SortFields(2)" property="Order" value="1" type="Double" /><column name="SortFields(2)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'usp_data', N'<table name="s17.usp_data"><columnFormats><column name="" property="ListObjectName" value="data" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="code" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="code" property="Address" value="$C$4" type="String" /><column name="code" property="ColumnWidth" value="25.57" type="Double" /><column name="code" property="NumberFormat" value="General" type="String" /><column name="section" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="section" property="Address" value="$D$4" type="String" /><column name="section" property="ColumnWidth" value="14.86" type="Double" /><column name="section" property="NumberFormat" value="General" type="String" /><column name="category" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category" property="Address" value="$E$4" type="String" /><column name="category" property="ColumnWidth" value="10.14" type="Double" /><column name="category" property="NumberFormat" value="General" type="String" /><column name="time" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="time" property="Address" value="$F$4" type="String" /><column name="time" property="ColumnWidth" value="6.71" type="Double" /><column name="time" property="NumberFormat" value="General" type="String" /><column name="account" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account" property="Address" value="$G$4" type="String" /><column name="account" property="ColumnWidth" value="9.43" type="Double" /><column name="account" property="NumberFormat" value="General" type="String" /><column name="account_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_name" property="Address" value="$H$4" type="String" /><column name="account_name" property="ColumnWidth" value="15.57" type="Double" /><column name="account_name" property="NumberFormat" value="General" type="String" /><column name="entity" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity" property="Address" value="$I$4" type="String" /><column name="entity" property="ColumnWidth" value="7.86" type="Double" /><column name="entity" property="NumberFormat" value="General" type="String" /><column name="entity_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity_name" property="Address" value="$J$4" type="String" /><column name="entity_name" property="ColumnWidth" value="13.86" type="Double" /><column name="entity_name" property="NumberFormat" value="General" type="String" /><column name="region" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region" property="Address" value="$K$4" type="String" /><column name="region" property="ColumnWidth" value="8.29" type="Double" /><column name="region" property="NumberFormat" value="General" type="String" /><column name="region_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_name" property="Address" value="$L$4" type="String" /><column name="region_name" property="ColumnWidth" value="14.29" type="Double" /><column name="region_name" property="NumberFormat" value="General" type="String" /><column name="product" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product" property="Address" value="$M$4" type="String" /><column name="product" property="ColumnWidth" value="9.43" type="Double" /><column name="product" property="NumberFormat" value="General" type="String" /><column name="product_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_name" property="Address" value="$N$4" type="String" /><column name="product_name" property="ColumnWidth" value="15.57" type="Double" /><column name="product_name" property="NumberFormat" value="General" type="String" /><column name="subaccount" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount" property="Address" value="$O$4" type="String" /><column name="subaccount" property="ColumnWidth" value="12.57" type="Double" /><column name="subaccount" property="NumberFormat" value="General" type="String" /><column name="subaccount_name" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_name" property="Address" value="$P$4" type="String" /><column name="subaccount_name" property="ColumnWidth" value="19.86" type="Double" /><column name="subaccount_name" property="NumberFormat" value="General" type="String" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="Address" value="$Q$4" type="String" /><column name="total" property="ColumnWidth" value="9.57" type="Double" /><column name="total" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="Address" value="$R$4" type="String" /><column name="01" property="ColumnWidth" value="8.57" type="Double" /><column name="01" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="Address" value="$S$4" type="String" /><column name="02" property="ColumnWidth" value="8.57" type="Double" /><column name="02" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="Address" value="$T$4" type="String" /><column name="03" property="ColumnWidth" value="8.57" type="Double" /><column name="03" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="Address" value="$U$4" type="String" /><column name="04" property="ColumnWidth" value="8.57" type="Double" /><column name="04" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="Address" value="$V$4" type="String" /><column name="05" property="ColumnWidth" value="8.57" type="Double" /><column name="05" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="Address" value="$W$4" type="String" /><column name="06" property="ColumnWidth" value="8.57" type="Double" /><column name="06" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="Address" value="$X$4" type="String" /><column name="07" property="ColumnWidth" value="8.57" type="Double" /><column name="07" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="Address" value="$Y$4" type="String" /><column name="08" property="ColumnWidth" value="8.57" type="Double" /><column name="08" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="Address" value="$Z$4" type="String" /><column name="09" property="ColumnWidth" value="8.57" type="Double" /><column name="09" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="Address" value="$AA$4" type="String" /><column name="10" property="ColumnWidth" value="8.57" type="Double" /><column name="10" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="Address" value="$AB$4" type="String" /><column name="11" property="ColumnWidth" value="8.57" type="Double" /><column name="11" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="Address" value="$AC$4" type="String" /><column name="12" property="ColumnWidth" value="8.57" type="Double" /><column name="12" property="NumberFormat" value="#,##0_ ;[Red]-#,##0 " type="String" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'usp_request', N'<table name="s17.usp_request"><columnFormats><column name="" property="ListObjectName" value="request" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="Address" value="$C$4" type="String" /><column name="row_index" property="NumberFormat" value="General" type="String" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="Address" value="$D$4" type="String" /><column name="row_format" property="NumberFormat" value="General" type="String" /><column name="row_format" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="row_format" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="row_format" property="Validation.Type" value="1" type="Double" /><column name="row_format" property="Validation.Operator" value="1" type="Double" /><column name="row_format" property="Validation.Formula1" value="-2147483648" type="String" /><column name="row_format" property="Validation.Formula2" value="2147483647" type="String" /><column name="row_format" property="Validation.AlertStyle" value="1" type="Double" /><column name="row_format" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="row_format" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="row_format" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="row_format" property="Validation.ErrorMessage" value="The column requires values of the int datatype." type="String" /><column name="row_format" property="Validation.ShowInput" value="True" type="Boolean" /><column name="row_format" property="Validation.ShowError" value="True" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="comment" property="Address" value="$E$4" type="String" /><column name="comment" property="ColumnWidth" value="12.29" type="Double" /><column name="comment" property="NumberFormat" value="General" type="String" /><column name="comment" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="comment" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="comment" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="comment" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="comment" property="Validation.Type" value="6" type="Double" /><column name="comment" property="Validation.Operator" value="8" type="Double" /><column name="comment" property="Validation.Formula1" value="255" type="String" /><column name="comment" property="Validation.AlertStyle" value="1" type="Double" /><column name="comment" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="comment" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="comment" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="comment" property="Validation.ErrorMessage" value="The column requires values of the nvarchar(255) datatype." type="String" /><column name="comment" property="Validation.ShowInput" value="True" type="Boolean" /><column name="comment" property="Validation.ShowError" value="True" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="Address" value="$F$4" type="String" /><column name="account_id" property="ColumnWidth" value="12.14" type="Double" /><column name="account_id" property="NumberFormat" value="General" type="String" /><column name="account_id" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="account_id" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="Address" value="$G$4" type="String" /><column name="subaccount_id" property="ColumnWidth" value="15.43" type="Double" /><column name="subaccount_id" property="NumberFormat" value="General" type="String" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="Address" value="$H$4" type="String" /><column name="product_id" property="ColumnWidth" value="12.14" type="Double" /><column name="product_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="Address" value="$I$4" type="String" /><column name="region_id" property="ColumnWidth" value="11" type="Double" /><column name="region_id" property="NumberFormat" value="General" type="String" /><column name="region_id" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="region_id" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="Address" value="$J$4" type="String" /><column name="total" property="FormulaR1C1" value="=[@01]+[@02]+[@03]+[@04]+[@05]+[@06]+[@07]+[@08]+[@09]+[@10]+[@11]+[@12]" type="String" /><column name="total" property="ColumnWidth" value="12.14" type="Double" /><column name="total" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="total" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="total" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="total" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="total" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="Address" value="$K$4" type="String" /><column name="01" property="ColumnWidth" value="11.14" type="Double" /><column name="01" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="01" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="01" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="01" property="Validation.Type" value="2" type="Double" /><column name="01" property="Validation.Operator" value="4" type="Double" /><column name="01" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="01" property="Validation.AlertStyle" value="1" type="Double" /><column name="01" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="01" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="01" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="01" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="01" property="Validation.ShowInput" value="True" type="Boolean" /><column name="01" property="Validation.ShowError" value="True" type="Boolean" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="Address" value="$L$4" type="String" /><column name="02" property="ColumnWidth" value="11.14" type="Double" /><column name="02" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="02" property="Validation.Type" value="2" type="Double" /><column name="02" property="Validation.Operator" value="4" type="Double" /><column name="02" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="02" property="Validation.AlertStyle" value="1" type="Double" /><column name="02" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="02" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="02" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="02" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="02" property="Validation.ShowInput" value="True" type="Boolean" /><column name="02" property="Validation.ShowError" value="True" type="Boolean" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="Address" value="$M$4" type="String" /><column name="03" property="ColumnWidth" value="11.14" type="Double" /><column name="03" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="03" property="Validation.Type" value="2" type="Double" /><column name="03" property="Validation.Operator" value="4" type="Double" /><column name="03" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="03" property="Validation.AlertStyle" value="1" type="Double" /><column name="03" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="03" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="03" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="03" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="03" property="Validation.ShowInput" value="True" type="Boolean" /><column name="03" property="Validation.ShowError" value="True" type="Boolean" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="Address" value="$N$4" type="String" /><column name="04" property="ColumnWidth" value="11.14" type="Double" /><column name="04" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="04" property="Validation.Type" value="2" type="Double" /><column name="04" property="Validation.Operator" value="4" type="Double" /><column name="04" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="04" property="Validation.AlertStyle" value="1" type="Double" /><column name="04" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="04" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="04" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="04" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="04" property="Validation.ShowInput" value="True" type="Boolean" /><column name="04" property="Validation.ShowError" value="True" type="Boolean" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="Address" value="$O$4" type="String" /><column name="05" property="ColumnWidth" value="11.14" type="Double" /><column name="05" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="05" property="Validation.Type" value="2" type="Double" /><column name="05" property="Validation.Operator" value="4" type="Double" /><column name="05" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="05" property="Validation.AlertStyle" value="1" type="Double" /><column name="05" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="05" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="05" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="05" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="05" property="Validation.ShowInput" value="True" type="Boolean" /><column name="05" property="Validation.ShowError" value="True" type="Boolean" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="Address" value="$P$4" type="String" /><column name="06" property="ColumnWidth" value="11.14" type="Double" /><column name="06" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="06" property="Validation.Type" value="2" type="Double" /><column name="06" property="Validation.Operator" value="4" type="Double" /><column name="06" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="06" property="Validation.AlertStyle" value="1" type="Double" /><column name="06" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="06" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="06" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="06" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="06" property="Validation.ShowInput" value="True" type="Boolean" /><column name="06" property="Validation.ShowError" value="True" type="Boolean" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="Address" value="$Q$4" type="String" /><column name="07" property="ColumnWidth" value="11.14" type="Double" /><column name="07" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="07" property="Validation.Type" value="2" type="Double" /><column name="07" property="Validation.Operator" value="4" type="Double" /><column name="07" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="07" property="Validation.AlertStyle" value="1" type="Double" /><column name="07" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="07" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="07" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="07" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="07" property="Validation.ShowInput" value="True" type="Boolean" /><column name="07" property="Validation.ShowError" value="True" type="Boolean" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="Address" value="$R$4" type="String" /><column name="08" property="ColumnWidth" value="11.14" type="Double" /><column name="08" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="08" property="Validation.Type" value="2" type="Double" /><column name="08" property="Validation.Operator" value="4" type="Double" /><column name="08" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="08" property="Validation.AlertStyle" value="1" type="Double" /><column name="08" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="08" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="08" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="08" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="08" property="Validation.ShowInput" value="True" type="Boolean" /><column name="08" property="Validation.ShowError" value="True" type="Boolean" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="Address" value="$S$4" type="String" /><column name="09" property="ColumnWidth" value="11.14" type="Double" /><column name="09" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="09" property="Validation.Type" value="2" type="Double" /><column name="09" property="Validation.Operator" value="4" type="Double" /><column name="09" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="09" property="Validation.AlertStyle" value="1" type="Double" /><column name="09" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="09" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="09" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="09" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="09" property="Validation.ShowInput" value="True" type="Boolean" /><column name="09" property="Validation.ShowError" value="True" type="Boolean" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="Address" value="$T$4" type="String" /><column name="10" property="ColumnWidth" value="11.14" type="Double" /><column name="10" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="10" property="Validation.Type" value="2" type="Double" /><column name="10" property="Validation.Operator" value="4" type="Double" /><column name="10" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="10" property="Validation.AlertStyle" value="1" type="Double" /><column name="10" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="10" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="10" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="10" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="10" property="Validation.ShowInput" value="True" type="Boolean" /><column name="10" property="Validation.ShowError" value="True" type="Boolean" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="Address" value="$U$4" type="String" /><column name="11" property="ColumnWidth" value="11.14" type="Double" /><column name="11" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="11" property="Validation.Type" value="2" type="Double" /><column name="11" property="Validation.Operator" value="4" type="Double" /><column name="11" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="11" property="Validation.AlertStyle" value="1" type="Double" /><column name="11" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="11" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="11" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="11" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="11" property="Validation.ShowInput" value="True" type="Boolean" /><column name="11" property="Validation.ShowError" value="True" type="Boolean" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="Address" value="$V$4" type="String" /><column name="12" property="ColumnWidth" value="11.14" type="Double" /><column name="12" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="12" property="BorderxlEdgeRight.LineStyle" value="1" type="Double" /><column name="12" property="BorderxlEdgeRight.Weight" value="-4138" type="Double" /><column name="12" property="Validation.Type" value="2" type="Double" /><column name="12" property="Validation.Operator" value="4" type="Double" /><column name="12" property="Validation.Formula1" value="-1.11222333444555E+29" type="String" /><column name="12" property="Validation.AlertStyle" value="1" type="Double" /><column name="12" property="Validation.IgnoreBlank" value="True" type="Boolean" /><column name="12" property="Validation.InCellDropdown" value="True" type="Boolean" /><column name="12" property="Validation.ErrorTitle" value="Datatype Control" type="String" /><column name="12" property="Validation.ErrorMessage" value="The column requires values of the float datatype." type="String" /><column name="12" property="Validation.ShowInput" value="True" type="Boolean" /><column name="12" property="Validation.ShowError" value="True" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_formulas" property="Address" value="$W$4" type="String" /><column name="row_formulas" property="NumberFormat" value="General" type="String" /><column name="row_formulas" property="BorderxlEdgeLeft.LineStyle" value="1" type="Double" /><column name="row_formulas" property="BorderxlEdgeLeft.Weight" value="-4138" type="Double" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="Address" value="$X$4" type="String" /><column name="row_comments" property="NumberFormat" value="#,##0.00_ ;[Red]-#,##0.00 ;" type="String" /><column name="_RowNum" property="FormatConditions(1).AppliesToTable" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).AppliesTo.Address" value="$B$4:$X$23" type="String" /><column name="_RowNum" property="FormatConditions(1).Type" value="2" type="Double" /><column name="_RowNum" property="FormatConditions(1).Priority" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Formula1" value="=$D4=1" type="String" /><column name="_RowNum" property="FormatConditions(1).Font.Bold" value="True" type="Boolean" /><column name="_RowNum" property="FormatConditions(1).Font.Color" value="16777215" type="Double" /><column name="_RowNum" property="FormatConditions(1).Font.ThemeColor" value="1" type="Double" /><column name="_RowNum" property="FormatConditions(1).Font.TintAndShade" value="0" type="Double" /><column name="_RowNum" property="FormatConditions(1).Interior.Color" value="6773025" type="Double" /><column name="SortFields(1)" property="KeyfieldName" value="_RowNum" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats><views><view name="Form"><column name="" property="ListObjectName" value="request" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="_RowNum" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /></view><view name="All columns"><column name="" property="ListObjectName" value="request" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_index" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_format" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="comment" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="account_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="subaccount_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="product_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="region_id" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="total" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="01" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="02" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="03" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="04" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="05" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="06" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="07" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="08" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="09" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="10" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="11" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="12" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_formulas" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="row_comments" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="SortFields(1)" property="KeyfieldName" value="_RowNum" type="String" /><column name="SortFields(1)" property="SortOn" value="0" type="Double" /><column name="SortFields(1)" property="Order" value="1" type="Double" /><column name="SortFields(1)" property="DataOption" value="0" type="Double" /></view></views></table>');
INSERT INTO xls.formats (TABLE_SCHEMA, TABLE_NAME, TABLE_EXCEL_FORMAT_XML) VALUES (N's17', N'usp_requests', N'<table name="s17.usp_requests"><columnFormats><column name="" property="ListObjectName" value="requests" type="String" /><column name="" property="ShowTotals" value="False" type="Boolean" /><column name="" property="TableStyle.Name" value="TableStyleMedium15" type="String" /><column name="" property="ShowTableStyleColumnStripes" value="False" type="Boolean" /><column name="" property="ShowTableStyleFirstColumn" value="False" type="Boolean" /><column name="" property="ShowShowTableStyleLastColumn" value="False" type="Boolean" /><column name="" property="ShowTableStyleRowStripes" value="False" type="Boolean" /><column name="_RowNum" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="_RowNum" property="Address" value="$B$4" type="String" /><column name="_RowNum" property="NumberFormat" value="General" type="String" /><column name="category_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="category_id" property="Address" value="$C$4" type="String" /><column name="category_id" property="NumberFormat" value="General" type="String" /><column name="time_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="time_id" property="Address" value="$D$4" type="String" /><column name="time_id" property="NumberFormat" value="General" type="String" /><column name="entity_id" property="EntireColumn.Hidden" value="True" type="Boolean" /><column name="entity_id" property="Address" value="$E$4" type="String" /><column name="entity_id" property="NumberFormat" value="General" type="String" /><column name="category" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="category" property="Address" value="$F$4" type="String" /><column name="category" property="ColumnWidth" value="13.57" type="Double" /><column name="category" property="NumberFormat" value="General" type="String" /><column name="time" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="time" property="Address" value="$G$4" type="String" /><column name="time" property="ColumnWidth" value="13.57" type="Double" /><column name="time" property="NumberFormat" value="General" type="String" /><column name="entity" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="entity" property="Address" value="$H$4" type="String" /><column name="entity" property="ColumnWidth" value="13.57" type="Double" /><column name="entity" property="NumberFormat" value="General" type="String" /><column name="last_update" property="EntireColumn.Hidden" value="False" type="Boolean" /><column name="last_update" property="Address" value="$I$4" type="String" /><column name="last_update" property="ColumnWidth" value="13" type="Double" /><column name="last_update" property="NumberFormat" value="m/d/yyyy" type="String" /><column name="" property="ActiveWindow.DisplayGridlines" value="False" type="Boolean" /><column name="" property="ActiveWindow.FreezePanes" value="True" type="Boolean" /><column name="" property="ActiveWindow.Split" value="True" type="Boolean" /><column name="" property="ActiveWindow.SplitRow" value="0" type="Double" /><column name="" property="ActiveWindow.SplitColumn" value="-2" type="Double" /><column name="" property="PageSetup.Orientation" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesWide" value="1" type="Double" /><column name="" property="PageSetup.FitToPagesTall" value="1" type="Double" /></columnFormats></table>');
GO

INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_requests', NULL, N'Actions', N's17', N'xl_actions_clone_requests', N'PROCEDURE', NULL, NULL, 1, 1);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_requests', NULL, N'ContextMenu', N's17', N'xl_actions_clean_requests', N'PROCEDURE', NULL, NULL, 1, 1);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'category_id', N'DefaultValue', NULL, NULL, N'ATTRIBUTE', N'1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'entity_id', N'DefaultValue', NULL, NULL, N'ATTRIBUTE', N'1', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'rows', N'DefaultValue', NULL, NULL, N'ATTRIBUTE', N'15', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'time_id', N'DefaultValue', NULL, NULL, N'ATTRIBUTE', N'2', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', NULL, N'DoNotSort', NULL, NULL, N'ATTRIBUTE', NULL, NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', NULL, N'Format', NULL, NULL, N'ATTRIBUTE', N'[{"format":"font-size:14px;min-height:21px;"},{"formula":"row_format=1","format":"background-color: rgb(247,247,247);font-weight:500;"}]', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'row_comments', N'KeepComments', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'row_formulas', N'KeepFormulas', NULL, NULL, N'ATTRIBUTE', N'rownum', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_data', N'category_id', N'ParameterValues', N's17', N'categories', N'TABLE', N'id, +name', N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_data', N'entity_id', N'ParameterValues', N's17', N'entities', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_data', N'time_id', N'ParameterValues', N's17', N'times', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'category_id', N'ParameterValues', N's17', N'categories', N'TABLE', N'id, +name', N'_NotNull', NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'entity_id', N'ParameterValues', N's17', N'entities', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'time_id', N'ParameterValues', N's17', N'times', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_requests', N'category_id', N'ParameterValues', N's17', N'categories', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_requests', N'entity_id', N'ParameterValues', N's17', N'entities', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_requests', N'time_id', N'ParameterValues', N's17', N'times', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clean_requests', N'category_id', N'ParameterValues', N's17', N'categories', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clean_requests', N'entity_id', N'ParameterValues', N's17', N'entities', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clean_requests', N'time_id', N'ParameterValues', N's17', N'times', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clone_requests', N'category_id', N'ParameterValues', N's17', N'categories', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clone_requests', N'entity_id', N'ParameterValues', N's17', N'entities', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clone_requests', N'target_category_id', N'ParameterValues', N's17', N'categories', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clone_requests', N'target_entity_id', N'ParameterValues', N's17', N'entities', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clone_requests', N'target_time_id', N'ParameterValues', N's17', N'times', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'xl_actions_clone_requests', N'time_id', N'ParameterValues', N's17', N'times', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'account_id', N'ValidationList', N's17', N'accounts', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'product_id', N'ValidationList', N's17', N'products', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'region_id', N'ValidationList', N's17', N'regions', N'TABLE', N'id, +name', NULL, NULL, NULL);
INSERT INTO xls.handlers (TABLE_SCHEMA, TABLE_NAME, COLUMN_NAME, EVENT_NAME, HANDLER_SCHEMA, HANDLER_NAME, HANDLER_TYPE, HANDLER_CODE, TARGET_WORKSHEET, MENU_ORDER, EDIT_PARAMETERS) VALUES (N's17', N'usp_request', N'subaccount_id', N'ValidationList', N's17', N'subaccounts', N'TABLE', N'id, +name', NULL, NULL, NULL);
GO

INSERT INTO xls.workbooks (NAME, TEMPLATE, DEFINITION, TABLE_SCHEMA) VALUES (N'Sample 17 - Budget Request.xlsx', N'https://www.savetodb.com/downloads/v10/sample17-user1.xlsx', N'members=s17.accounts,s17,True,$B$3,,{"Parameters":{},"ListObjectName":"members"}
request=s17.usp_request,s17,False,$B$3,,{"Parameters":{"category_id":1,"time_id":2,"entity_id":1,"rows":20},"ListObjectName":"request"}
requests=s17.usp_requests,s17,False,$B$3,,{"Parameters":{"category_id":null,"time_id":null,"entity_id":null},"ListObjectName":"requests"}
data=s17.usp_data,s17,False,$B$3,,{"Parameters":{"category_id":1,"time_id":2,"entity_id":null},"ListObjectName":"data"}
handlers=xls.handlers,(Default),True,$B$3,,{"Parameters":{"TABLE_SCHEMA":"s17","EVENT_NAME":null,"HANDLER_TYPE":null},"ListObjectName":"handlers"}', N's17');
GO

print 'Application installed';
